#
# spec file for package lzlib
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname liblz1
Name:           lzlib
Version:        1.14
Release:        1.2
Summary:        LZMA Compression and Decompression Library
License:        BSD-2-Clause AND GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.nongnu.org/lzip/lzlib.html
Source:         https://download.savannah.gnu.org/releases/lzip/lzlib/%name-%version.tar.gz
Source2:        https://download.savannah.gnu.org/releases/lzip/lzlib/%name-%version.tar.gz.sig
Source3:        %name.keyring
PreReq:         %install_info_prereq

%description
The lzlib compression library provides in-memory LZMA compression and
decompression functions, including integrity checking of the
decompressed data. The compressed data format used by the library is
the lzip format.

%package -n %lname
Summary:        LZMA Compression and Decompression Library
Group:          System/Libraries

%description -n %lname
The lzlib compression library provides in-memory LZMA compression and
decompression functions, including integrity checking of the
decompressed data. The compressed data format used by the library is
the lzip format.

%package devel
Summary:        LZMA Compression and Decompression Library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Obsoletes:      lzlib-devel < %version-%release
Provides:       lzlib-devel = %version-%release

%description devel
The lzlib compression library provides in-memory LZMA compression and
decompression functions, including integrity checking of the
decompressed data. The compressed data format used by the library is
the lzip format.

This subpackage contains libraries and header files for developing
applications that want to make use of libcerror.

%prep
%autosetup

%build
# not autoconf!
# don't use the configure macro here, as it will cause the configure script to
# skip parameters as soon as it encounters one that it doesn't understand
mkdir build
pushd build/
../configure --prefix="%_prefix" --bindir="%_bindir" --datadir="%_datadir" \
	--includedir="%_includedir" --infodir="%_infodir" --libdir="%_libdir" \
	--mandir="%_mandir" --sysconfdir="%_sysconfdir" --enable-shared \
	CC="%__cc" CFLAGS="%optflags" CXX="%__cxx" CXXFLAGS="%optflags"
%make_build
popd

%install
pushd build/
%make_install LDCONFIG=true
popd
# configure had no --disable-static
rm -f "%buildroot/%_libdir"/*.a

%check
pushd build/
%make_build check
popd

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%post devel
%install_info --info-dir="%_infodir" "%_infodir/%name.info%ext_info"

%preun devel
%install_info_delete --info-dir="%_infodir" "%_infodir/%name.info%ext_info"

%files -n %lname
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%_libdir/liblz.so.*

%files devel
%_includedir/lzlib.h
%_libdir/liblz.so
%_infodir/lzlib.info*

%changelog
* Thu Feb  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.14
  * The option -o/--output of minilzip now preserves dates,
    permissions, and ownership of the file when (de)compressing
    exactly one file.
* Fri Jan 28 2022 Dirk Müller <dmueller@suse.com>
- update to 1.13:
  * The variables AR and ARFLAGS can now be set from configure.
  * In case of error in a numerical argument to a command line option, minilzip
    now shows the name of the option and the range of valid values.
  * 'minilzip --check-lib' now checks that LZ_API_VERSION and LZ_version_string
    match.
  * Several descriptions have been improved in manual, '--help', and man page.
  * The texinfo category of the manual has been changed from 'Data Compression'
    to 'Compression' to match that of gzip.
* Wed Jan 20 2021 Dirk Müller <dmueller@suse.com>
- Update to 1.12:
  * see included NEWS
  * The value of the version test macro 'LZ_API_VERSION' is now
    defined as 1000 * major + minor. For version 1.12 it is 1012.
  * The new function 'LZ_api_version', which returns the
    LZ_API_VERSION of the library object code being used, has
    been added to lzlib.
  * Decompression speed has been slightly increased.
  * The new option '--check-lib', which compares the version of
    lzlib used to compile minilzip with the version actually
    being used, has been added to minilzip.
  * Minilzip now reports an error if a file name is empty (minilzip -t "").
  * Option '-o, --output' now behaves like '-c, --stdout', but
    sending the output unconditionally to a file instead of to
    standard output. See the new description of '-o' in the
    manual. This change is not backwards compatible.
  * When using '-c' or '-o', minilzip now checks whether the
    output is a terminal only once.
  * The words 'decompressed' and 'compressed' have been replaced
    with the shorter 'out' and 'in' in the verbose output of
    minilzip when decompressing or testing.
  * It has been documented in the manual that
    'LZ_(de)compress_close' and 'LZ_(de)compress_errno' can be
    called with a null argument.
  * Bugfixes, documentation updates.
* Wed Feb  6 2019 Jan Engelhardt <jengelh@inai.de>
- Move to final release 1.11
  * No visible changes
* Wed Feb  6 2019 Jan Engelhardt <jengelh@inai.de>
- Update License field as per SR 658030 review
* Fri Dec 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.11~rc2
  * In case of decompression error caused by corrupt or truncated data,
    LZ_decompress_read now does not signal the error immediately
    to the application, but waits until all decoded bytes have
    been read. This allows tools like tarlz to recover as much
    data as possible from damaged members.
* Sun Feb 18 2018 avindra@opensuse.org
- Update to version 1.10:
  * LZ_compress_finish now adjusts dictionary size for each member.
  * lzlib.c (LZ_decompress_read): Detect corrupt header with HD=3.
  * main.c: Added new option '--loose-trailing'.
  * main.c (main): Option '-S, --volume-size' now keeps input files.
  * main.c: Replaced 'bits/byte' with inverse compression ratio.
  * main.c: Show final diagnostic when testing multiple files.
  * main.c: Do not add a second .lz extension to the arg of -o.
  * main.c: Show dictionary size at verbosity level 4 (-vvvv).
  * lzlib.texi: Added chapter 'Invoking minilzip'.
- Includes 1.9:
  * Compression time of option '-0' has been reduced by 3%%.
  * Compression time of options -1 to -9 has been reduced by 1%%.
  * Decompression time has been reduced by 3%%.
  * main.c: Continue testing if any input file is a terminal.
  * License of the library changed to "2-clause BSD".
- partial cleanup with spec-cleaner
* Tue May 31 2016 mpluskal@suse.com
- Update to version 1.8:
  * decoder.c (LZd_verify_trailer): Removed test of final code.
  * main.c: Added new option '-a, --trailing-error'.
  * main.c (main): Delete '--output' file if infd is a terminal.
  * main.c (main): Don't use stdin more than once.
  * configure: Avoid warning on some shells when testing for gcc.
  * Makefile.in: Detect the existence of install-info.
  * testsuite/check.sh: A POSIX shell is required to run the tests.
  * testsuite/check.sh: Don't check error messages.
- Move info scriplet to preun
* Thu Aug  6 2015 jengelh@inai.de
- Update to new upstream release 1.7
  * The fast encoder, which produces a compression speed and ratio
  comparable to those of gzip, has been ported from lzip.
  * The option "-0" has been ported from lzip to minilzip.
  * If all the data to be compressed are written in advance, lzlib
  will automatically adjust the header of the compressed data to
  use the smallest possible dictionary size. This feature reduces
  the amount of memory needed for decompression and allows minilzip
  to produce identical compressed output as lzip.
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 1.6
  * Compression ratio of option -9 has been slightly increased.
  * Minilzip now copies file dates, permissions, and ownership like
  `cp -p`. (If the user ID or the group ID cannot be duplicated,
  the file permission bits S_ISUID and S_ISGID are cleared).
  * The license has been changed to "GPL version 2 or later with link
  exception".
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Sun Sep 29 2013 jengelh@inai.de
- Update to new upstream release 1.5
  * Decompression support for deprecated version 0 files has been
  removed.
  * A bug has been fixed that would make an instance of
  "struct LZ_Encoder" unresponsive if "LZ_compress_sync_flush" were
  called at the wrong moment.
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 1.4
  * Compression ratio has been slightly increased.
  * Compression time has been reduced by 8%%.
  * Decompression time has been reduced by 7%%.
  * Arguments and return values of functions in lzlib.h have been
  changed from "long long" to "unsigned long long".
  * "LZ_decompress_read" now tells "header error" from "unexpected
  eof" the same way as lzip does when the EOF happens at the header.
- Do signature verification
- Base name of devel package on main name
- Remove static libraries from installation
- Wrap description at 70 cols
* Thu Apr 12 2012 pascal.bleser@opensuse.org
- update to 1.3:
  * Lzlib has been translated to C from the C++ source of lzlib 1.2. This has
    been done to avoid the dependency on libstdc++, making lzlib useful in more
    environments
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Thu Oct 27 2011 pascal.bleser@opensuse.org
- update to 1.2:
  * for large values of "--match-length", compression ratio has been slightly
    increased and compression time has been reduced by up to 6%%
  * the option "-F, --recompress", which forces recompression of files whose
    name already has the ".lz" or ".tlz" suffix, has been added to minilzip
* Wed Dec  8 2010 pascal.bleser@opensuse.org
- update to 1.0:
  * new functions: LZ_decompress_member_finished, LZ_decompress_member_version,
    LZ_decompress_dictionary_size, LZ_decompress_data_crc
  * variables declared "extern" have been encapsulated in a namespace
  * a warning about fchown's return value being ignored has been fixed
  * input_buffer has been integrated in Range_decoder, simplifying the code and
    making decompression slightly faster
- SONAME changed from 0 to 1
* Mon Feb 15 2010 pascal.bleser@opensuse.org
- update to 0.9:
  * compression time has been reduced by 8%%
* Tue Jan 19 2010 pascal.bleser@opensuse.org
- initial package (0.8)
